{
    "$graph": [
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "id": "#checkInput.cwl/fastq_directory"
                }
            ],
            "steps": [
                {
                    "run": "#findFiles.cwl",
                    "in": [
                        {
                            "source": "#checkInput.cwl/fastq_directory",
                            "id": "#checkInput.cwl/check-files/fastq_directory"
                        }
                    ],
                    "out": [
                        "#checkInput.cwl/check-files/value"
                    ],
                    "id": "#checkInput.cwl/check-files"
                },
                {
                    "run": "#sendFiles.cwl",
                    "scatter": "#checkInput.cwl/send-files/fastq_name",
                    "in": [
                        {
                            "source": "#checkInput.cwl/fastq_directory",
                            "id": "#checkInput.cwl/send-files/fastq_directory"
                        },
                        {
                            "source": "#checkInput.cwl/check-files/value",
                            "id": "#checkInput.cwl/send-files/fastq_name"
                        }
                    ],
                    "out": [
                        "#checkInput.cwl/send-files/read_1",
                        "#checkInput.cwl/send-files/read_2"
                    ],
                    "id": "#checkInput.cwl/send-files"
                }
            ],
            "id": "#checkInput.cwl",
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#checkInput.cwl/send-files/read_1",
                    "id": "#checkInput.cwl/read_1"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#checkInput.cwl/send-files/read_2",
                    "id": "#checkInput.cwl/read_2"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "scontaldo/checkinput",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "bash",
                "/findFiles.sh"
            ],
            "stdout": "cwl.output.json",
            "inputs": [
                {
                    "type": "Directory",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#findFiles.cwl/fastq_directory"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#findFiles.cwl/value"
                }
            ],
            "id": "#findFiles.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "bash",
                "/sendFiles.sh"
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "scontaldo/checkinput",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#sendFiles.cwl/fastq_directory"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#sendFiles.cwl/fastq_name"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*_R1*.fastq.gz"
                    },
                    "id": "#sendFiles.cwl/read_1"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*_R2*.fastq.gz"
                    },
                    "id": "#sendFiles.cwl/read_2"
                }
            ],
            "id": "#sendFiles.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "scontaldo/kraken2:v2.1.2",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "python3",
                "/computeAlpha.py"
            ],
            "inputs": [
                {
                    "doc": "",
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#computeAlpha.cwl/total_otu"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "alphadiv.csv"
                    },
                    "id": "#computeAlpha.cwl/alpha_div"
                }
            ],
            "id": "#computeAlpha.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "scontaldo/kraken2:v2.1.2",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "python3",
                "/countTotalOTU.py"
            ],
            "inputs": [
                {
                    "doc": "",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#countTotalOTU.cwl/otus"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "otu_total.csv"
                    },
                    "id": "#countTotalOTU.cwl/total_otu"
                }
            ],
            "id": "#countTotalOTU.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Retrieve OTU from kraken2 report \n",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "scontaldo/kraken2:v2.1.2",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "python3",
                "/getOTU.py"
            ],
            "inputs": [
                {
                    "doc": "",
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#getOTU.cwl/kraken_report"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.kraken_report.nameroot)_S.tsv"
                    },
                    "id": "#getOTU.cwl/otu_table"
                }
            ],
            "id": "#getOTU.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Filter human reads \n",
            "requirements": [
                {
                    "listing": [
                        "$(inputs.index)"
                    ],
                    "class": "InitialWorkDirRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "scontaldo/humanmapper",
                    "class": "DockerRequirement"
                },
                {
                    "coresMax": "$(inputs.threads)",
                    "class": "ResourceRequirement"
                }
            ],
            "baseCommand": [
                "bash",
                "/scripts/humanMapper.sh"
            ],
            "inputs": [
                {
                    "doc": "Index used as reference",
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "secondaryFiles": [
                        {
                            "pattern": ".amb",
                            "required": null
                        },
                        {
                            "pattern": ".ann",
                            "required": null
                        },
                        {
                            "pattern": ".bwt",
                            "required": null
                        },
                        {
                            "pattern": ".fai",
                            "required": null
                        },
                        {
                            "pattern": ".pac",
                            "required": null
                        },
                        {
                            "pattern": ".sa",
                            "required": null
                        }
                    ],
                    "id": "#humanMapper.cwl/index"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#humanMapper.cwl/read_1"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#humanMapper.cwl/read_2"
                },
                {
                    "doc": "Maximum number of compute threads",
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 1,
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#humanMapper.cwl/threads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*_unmapped_R1.fastq.gz"
                    },
                    "id": "#humanMapper.cwl/unmapped_R1"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*_unmapped_R2.fastq.gz"
                    },
                    "id": "#humanMapper.cwl/unmapped_R2"
                }
            ],
            "id": "#humanMapper.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Get .biom from kraken results \n",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "scontaldo/kraken2:v2.1.2",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "kraken-biom"
            ],
            "inputs": [
                {
                    "doc": "",
                    "type": "string",
                    "default": "table.biom",
                    "inputBinding": {
                        "position": 3,
                        "prefix": "-o"
                    },
                    "id": "#kraken-biom.cwl/biom_name"
                },
                {
                    "doc": "",
                    "type": "string",
                    "default": "json",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--fmt"
                    },
                    "id": "#kraken-biom.cwl/fmt"
                },
                {
                    "doc": "Kraken Report",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#kraken-biom.cwl/kraken_report"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.biom_name)"
                    },
                    "id": "#kraken-biom.cwl/biom"
                }
            ],
            "id": "#kraken-biom.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Kraken2 mapping \n",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "scontaldo/kraken2:v2.1.2",
                    "class": "DockerRequirement"
                },
                {
                    "coresMax": "$(inputs.threads)",
                    "class": "ResourceRequirement"
                }
            ],
            "baseCommand": [
                "bash",
                "/kraken2.sh"
            ],
            "inputs": [
                {
                    "type": [
                        "Directory",
                        "File"
                    ],
                    "label": "Kraken 2 DB",
                    "doc": "(either a File refer to the hash.k2d file in the DB or a Directory to reference the entire directory)",
                    "inputBinding": {
                        "position": 2,
                        "valueFrom": "${ return (self.class == \"File\") ? self.dirname : self.path }\n"
                    },
                    "secondaryFiles": [
                        {
                            "pattern": "$(\"opts.k2d\")",
                            "required": null
                        },
                        {
                            "pattern": "$(\"taxo.k2d\")",
                            "required": null
                        }
                    ],
                    "id": "#kraken2.cwl/db_path"
                },
                {
                    "doc": "",
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#kraken2.cwl/read_1"
                },
                {
                    "doc": "",
                    "type": "File",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#kraken2.cwl/read_2"
                },
                {
                    "doc": "Maximum number of compute threads",
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 1,
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#kraken2.cwl/threads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.kraken2"
                    },
                    "id": "#kraken2.cwl/kraken2"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.report"
                    },
                    "id": "#kraken2.cwl/report"
                }
            ],
            "id": "#kraken2.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "Directory",
                        "File"
                    ],
                    "secondaryFiles": [
                        {
                            "pattern": "$(\"opts.k2d\")",
                            "required": null
                        },
                        {
                            "pattern": "$(\"taxo.k2d\")",
                            "required": null
                        }
                    ],
                    "id": "#main/db_path"
                },
                {
                    "type": "Directory",
                    "id": "#main/fastq_directory"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        {
                            "pattern": ".amb",
                            "required": null
                        },
                        {
                            "pattern": ".ann",
                            "required": null
                        },
                        {
                            "pattern": ".bwt",
                            "required": null
                        },
                        {
                            "pattern": ".fai",
                            "required": null
                        },
                        {
                            "pattern": ".pac",
                            "required": null
                        },
                        {
                            "pattern": ".sa",
                            "required": null
                        }
                    ],
                    "id": "#main/index"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/threads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/compute-alpha/alpha_div",
                    "id": "#main/compute-alpha_output"
                },
                {
                    "type": "File",
                    "outputSource": "#main/count-total-otu/total_otu",
                    "id": "#main/count-total-otu_output"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/get-otu/otu_table",
                    "id": "#main/get-otu_output"
                },
                {
                    "type": "File",
                    "outputSource": "#main/kraken-biom/biom",
                    "id": "#main/kraken-biom_output"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/kraken2/kraken2",
                    "id": "#main/kraken2_output"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/kraken2/report",
                    "id": "#main/kraken2_report"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/humanmapper/unmapped_R1",
                    "id": "#main/unmapped_R1"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/humanmapper/unmapped_R2",
                    "id": "#main/unmapped_R2"
                }
            ],
            "steps": [
                {
                    "run": "#checkInput.cwl",
                    "in": [
                        {
                            "source": "#main/fastq_directory",
                            "id": "#main/check-input/fastq_directory"
                        }
                    ],
                    "out": [
                        "#main/check-input/read_1",
                        "#main/check-input/read_2"
                    ],
                    "id": "#main/check-input"
                },
                {
                    "run": "#computeAlpha.cwl",
                    "in": [
                        {
                            "source": "#main/count-total-otu/total_otu",
                            "id": "#main/compute-alpha/total_otu"
                        }
                    ],
                    "out": [
                        "#main/compute-alpha/alpha_div"
                    ],
                    "id": "#main/compute-alpha"
                },
                {
                    "run": "#countTotalOTU.cwl",
                    "in": [
                        {
                            "source": "#main/get-otu/otu_table",
                            "id": "#main/count-total-otu/otus"
                        }
                    ],
                    "out": [
                        "#main/count-total-otu/total_otu"
                    ],
                    "id": "#main/count-total-otu"
                },
                {
                    "run": "#getOTU.cwl",
                    "scatter": "#main/get-otu/kraken_report",
                    "in": [
                        {
                            "source": "#main/kraken2/report",
                            "id": "#main/get-otu/kraken_report"
                        }
                    ],
                    "out": [
                        "#main/get-otu/otu_table"
                    ],
                    "id": "#main/get-otu"
                },
                {
                    "run": "#humanMapper.cwl",
                    "scatter": [
                        "#main/humanmapper/read_1",
                        "#main/humanmapper/read_2"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#main/index",
                            "id": "#main/humanmapper/index"
                        },
                        {
                            "source": "#main/check-input/read_1",
                            "id": "#main/humanmapper/read_1"
                        },
                        {
                            "source": "#main/check-input/read_2",
                            "id": "#main/humanmapper/read_2"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/humanmapper/threads"
                        }
                    ],
                    "out": [
                        "#main/humanmapper/unmapped_R1",
                        "#main/humanmapper/unmapped_R2"
                    ],
                    "id": "#main/humanmapper"
                },
                {
                    "run": "#kraken-biom.cwl",
                    "in": [
                        {
                            "source": "#main/kraken2/report",
                            "id": "#main/kraken-biom/kraken_report"
                        }
                    ],
                    "out": [
                        "#main/kraken-biom/biom"
                    ],
                    "id": "#main/kraken-biom"
                },
                {
                    "run": "#kraken2.cwl",
                    "scatter": [
                        "#main/kraken2/read_1",
                        "#main/kraken2/read_2"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#main/db_path",
                            "id": "#main/kraken2/db_path"
                        },
                        {
                            "source": "#main/humanmapper/unmapped_R1",
                            "id": "#main/kraken2/read_1"
                        },
                        {
                            "source": "#main/humanmapper/unmapped_R2",
                            "id": "#main/kraken2/read_2"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/kraken2/threads"
                        }
                    ],
                    "out": [
                        "#main/kraken2/kraken2",
                        "#main/kraken2/report"
                    ],
                    "id": "#main/kraken2"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.2"
}
